Class: LLMExperiment::App
- Inherits:
-
Data
- Object
- Data
- LLMExperiment::App
- Defined in:
- lib/llm_experiment/experiment.rb
Instance Attribute Summary collapse
-
#branch_prefix ⇒ Object
readonly
Returns the value of attribute branch_prefix.
-
#bundler ⇒ Object
readonly
Returns the value of attribute bundler.
-
#database ⇒ Object
readonly
Returns the value of attribute database.
-
#db_prepare ⇒ Object
readonly
Returns the value of attribute db_prepare.
-
#key ⇒ Object
readonly
Returns the value of attribute key.
-
#neutralize ⇒ Object
readonly
Returns the value of attribute neutralize.
-
#publish_transcripts ⇒ Object
readonly
Returns the value of attribute publish_transcripts.
-
#ruby ⇒ Object
readonly
Returns the value of attribute ruby.
-
#suite_ran_pattern ⇒ Object
readonly
Returns the value of attribute suite_ran_pattern.
-
#test_command ⇒ Object
readonly
Returns the value of attribute test_command.
Instance Method Summary collapse
- #image ⇒ Object
-
#repo_path ⇒ Object
Host checkout paths never live in experiment.yml; they identify the machine and belong in the environment (.apps.local convention).
Instance Attribute Details
#branch_prefix ⇒ Object (readonly)
Returns the value of attribute branch_prefix
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def branch_prefix @branch_prefix end |
#bundler ⇒ Object (readonly)
Returns the value of attribute bundler
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def bundler @bundler end |
#database ⇒ Object (readonly)
Returns the value of attribute database
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def database @database end |
#db_prepare ⇒ Object (readonly)
Returns the value of attribute db_prepare
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def db_prepare @db_prepare end |
#key ⇒ Object (readonly)
Returns the value of attribute key
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def key @key end |
#neutralize ⇒ Object (readonly)
Returns the value of attribute neutralize
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def neutralize @neutralize end |
#publish_transcripts ⇒ Object (readonly)
Returns the value of attribute publish_transcripts
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def publish_transcripts @publish_transcripts end |
#ruby ⇒ Object (readonly)
Returns the value of attribute ruby
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def ruby @ruby end |
#suite_ran_pattern ⇒ Object (readonly)
Returns the value of attribute suite_ran_pattern
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def suite_ran_pattern @suite_ran_pattern end |
#test_command ⇒ Object (readonly)
Returns the value of attribute test_command
6 7 8 |
# File 'lib/llm_experiment/experiment.rb', line 6 def test_command @test_command end |
Instance Method Details
#image ⇒ Object
14 15 16 |
# File 'lib/llm_experiment/experiment.rb', line 14 def image "llmx-app-#{key}:latest" end |
#repo_path ⇒ Object
Host checkout paths never live in experiment.yml; they identify the machine and belong in the environment (.apps.local convention).
10 11 12 |
# File 'lib/llm_experiment/experiment.rb', line 10 def repo_path ENV["LLMX_APP_#{key.upcase}"] end |